;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "org-roam-ql-ql" "20251030.2042"
  "Intgrating org-roam and org-ql."
  '((emacs       "28")
    (org-roam-ql "0.1")
    (org-ql      "0.8.2")
    (org-roam    "2.2.0")
    (s           "1.12.0")
    (transient   "0.4"))
  :url "https://github.com/ahmed-shariff/org-roam-ql"
  :commit "cdf6b11279783346607542dfac07c74d8651a650"
  :revdesc "cdf6b1127978")
